## 限售股解禁

接口：share_float

描述：获取限售股解禁

限量：单次最大6000条，总量不限制

积分：120分可调取，每分钟内限制次数，超过5000积分频次相对较高，具体请参阅积分获取办法 

输入参数

| 名称 | 类型 | 必选 | 描述 |
| --- | --- | --- | --- |
| ts_code | str | N | TS股票代码 |
| ann_date | str | N | 公告日期（日期格式：YYYYMMDD，下同） |
| float_date | str | N | 解禁日期 |
| start_date | str | N | 解禁开始日期 |
| end_date | str | N | 解禁结束日期 |

输出参数

| 名称 | 类型 | 默认显示 | 描述 |
| --- | --- | --- | --- |
| ts_code | str | Y | TS代码 |
| ann_date | str | Y | 公告日期 |
| float_date | str | Y | 解禁日期 |
| float_share | float | Y | 流通股份(股) |
| float_ratio | float | Y | 流通股份占总股本比率 |
| holder_name | str | Y | 股东名称 |
| share_type | str | Y | 股份类型 |

接口使用

```python
pro = ts.pro_api()

df = pro.share_float(ann_date='20181220')
```

数据示例

```python
ts_code    ann_date float_date  float_share  float_ratio         holder_name  \
0   000998.SZ  20181220   20211221   25076106.0       1.9041              王义波   
```